aboutsummaryrefslogtreecommitdiff
path: root/src/make.bash
diff options
context:
space:
mode:
Diffstat (limited to 'src/make.bash')
-rwxr-xr-xsrc/make.bash14
1 files changed, 8 insertions, 6 deletions
diff --git a/src/make.bash b/src/make.bash
index 4616502cec..c07f39bb40 100755
--- a/src/make.bash
+++ b/src/make.bash
@@ -67,13 +67,15 @@
# timing information to this file. Useful for profiling where the
# time goes when these scripts run.
#
# GOROOT_BOOTSTRAP: A working Go tree >= Go 1.17 for bootstrap.
# If $GOROOT_BOOTSTRAP/bin/go is missing, $(go env GOROOT) is
# tried for all "go" in $PATH. By default, one of $HOME/go1.17,
# $HOME/sdk/go1.17, or $HOME/go1.4, whichever exists, in that order.
# We still check $HOME/go1.4 to allow for build scripts that still hard-code
# that name even though they put newer Go toolchains there.
+bootgo=1.17.13
+
set -e
if [ ! -f run.bash ]; then
@@ -152,7 +154,7 @@ fi
goroot_bootstrap_set=${GOROOT_BOOTSTRAP+"true"}
if [ -z "$GOROOT_BOOTSTRAP" ]; then
GOROOT_BOOTSTRAP="$HOME/go1.4"
- for d in sdk/go1.17 go1.17; do
+ for d in sdk/go$bootgo go$bootgo; do
if [ -d "$HOME/$d" ]; then
GOROOT_BOOTSTRAP="$HOME/$d"
fi
@@ -175,7 +177,7 @@ IFS=$'\n'; for go_exe in $(type -ap go); do
done; unset IFS
if [ ! -x "$GOROOT_BOOTSTRAP/bin/go" ]; then
echo "ERROR: Cannot find $GOROOT_BOOTSTRAP/bin/go." >&2
- echo "Set \$GOROOT_BOOTSTRAP to a working Go tree >= Go 1.17." >&2
+ echo "Set \$GOROOT_BOOTSTRAP to a working Go tree >= Go $bootgo." >&2
exit 1
fi
# Get the exact bootstrap toolchain version to help with debugging.
@@ -188,7 +190,7 @@ if $verbose; then
fi
if [ "$GOROOT_BOOTSTRAP" = "$GOROOT" ]; then
echo "ERROR: \$GOROOT_BOOTSTRAP must not be set to \$GOROOT" >&2
- echo "Set \$GOROOT_BOOTSTRAP to a working Go tree >= Go 1.17." >&2
+ echo "Set \$GOROOT_BOOTSTRAP to a working Go tree >= Go $bootgo." >&2
exit 1
fi
rm -f cmd/dist/dist
@@ -67,13 +67,15 @@
# time goes when these scripts run.
#
-# GOROOT_BOOTSTRAP: A working Go tree >= Go 1.17 for bootstrap.
+# GOROOT_BOOTSTRAP: A working Go tree >= Go 1.17.13 for bootstrap.
# If $GOROOT_BOOTSTRAP/bin/go is missing, $(go env GOROOT) is
@@ -67,13 +67,15 @@
# If $GOROOT_BOOTSTRAP/bin/go is missing, $(go env GOROOT) is
-# tried for all "go" in $PATH. By default, one of $HOME/go1.17,
-# $HOME/sdk/go1.17, or $HOME/go1.4, whichever exists, in that order.
+# tried for all "go" in $PATH. By default, one of $HOME/go1.17.13,
+# $HOME/sdk/go1.17.13, or $HOME/go1.4, whichever exists, in that order.
# We still check $HOME/go1.4 to allow for build scripts that still hard-code
# that name even though they put newer Go toolchains there.